Page Menu
Home
Phabricator
Search
Configure Global Search
Log In
Files
F15427277
D19783.diff
No One
Temporary
Actions
View File
Edit File
Delete File
View Transforms
Subscribe
Mute Notifications
Award Token
Flag For Later
Size
2 KB
Referenced Files
None
Subscribers
None
D19783.diff
View Options
diff --git a/src/xsprintf/qsprintf.php b/src/xsprintf/qsprintf.php
--- a/src/xsprintf/qsprintf.php
+++ b/src/xsprintf/qsprintf.php
@@ -32,8 +32,9 @@
* %K ("Comment")
* Escapes a comment.
*
* %Q ("Query Fragment")
* Injects a query fragment from a prior call to qsprintf().
*
* %R ("Database and Table Reference")
* Behaves like "%T.%T" and prints a full reference to a table including
@@ -177,6 +178,24 @@
}
$value = implode(', ', $value);
break;
+ case 'Q':
+ foreach ($value as $k => $v) {
+ $value[$k] = $v->getUnmaskedString();
+ }
+ $value = implode(', ', $value);
+ break;
+ case 'O':
+ foreach ($value as $k => $v) {
+ $value[$k] = $v->getUnmaskedString();
+ }
+ $value = '(('.implode(') OR (', $value).'))';
+ break;
+ case 'A':
+ foreach ($value as $k => $v) {
+ $value[$k] = $v->getUnmaskedString();
+ }
+ $value = '(('.implode(') AND (', $value).'))';
+ break;
default:
throw new XsprintfUnknownConversionException("%L{$next}");
}
@@ -292,6 +311,9 @@
case 'LC':
case 'LB':
case 'Lf':
+ case 'LQ':
+ case 'LA':
+ case 'LO':
if (!is_array($value)) {
throw new AphrontParameterQueryException(
$query,
@@ -315,6 +337,19 @@
function qsprintf_check_scalar_type($value, $type, $query) {
switch ($type) {
+ case 'LQ':
+ case 'LA':
+ case 'LO':
+ if (!($value instanceof PhutilQueryString)) {
+ throw new AphrontParameterQueryException(
+ $query,
+ pht(
+ 'Expected a list of PhutilQueryString objects for %%%s '.
+ 'conversion.',
+ $type));
+ }
+ break;
+
case 'Q':
// TODO: See T13217. Remove this eventually.
if (is_string($value)) {
@@ -32,8 +32,9 @@
* Escapes a comment.
*
- * %Q ("Query Fragment")
- * Injects a query fragment from a prior call to qsprintf().
+ * %Q, %LA, %LO, %LQ ("Query Fragment")
+ * Injects a query fragment from a prior call to qsprintf(). The list
+ * variants join a list of query fragments with AND, OR, or comma.
*
* %R ("Database and Table Reference")
File Metadata
Details
Attached
Mime Type
text/plain
Expires
Mon, Mar 24, 1:30 PM (1 w, 5 d ago)
Storage Engine
blob
Storage Format
Encrypted (AES-256-CBC)
Storage Handle
7688217
Default Alt Text
D19783.diff (2 KB)
Attached To
Mode
D19783: Support %LA (AND), %LO (OR) and %LQ (comma) conversions for qsprintf() to improve safety
Attached
Detach File
Event Timeline
Log In to Comment